@@ -1,33 +1,32 @@
 ##############################################################################
 #      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic-More/lib/Perl/Critic/Policy/ErrorHandling/RequireUseOfExceptions.pm $
-#     $Date: 2008-05-18 19:30:24 -0500 (Sun, 18 May 2008) $
-#   $Author: clonezone $
-# $Revision: 2372 $
+#     $Date: 2007-08-08 20:17:06 -0500 (Wed, 08 Aug 2007) $
+#   $Author: chrisdolan $
+# $Revision: 1825 $
 ##############################################################################
 
 package Perl::Critic::Policy::ErrorHandling::RequireUseOfExceptions;
 
-use 5.006;
+use v5.6;
 use strict;
 use warnings;
-
 use Readonly;
 
 use Perl::Critic::Utils qw{ :severities :classification :data_conversion };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '0.999_002';
+our $VERSION = 0.14;
 
 #-----------------------------------------------------------------------------
 
-sub default_severity     { return $SEVERITY_HIGH }
-sub default_themes       { return qw< more maintenance > }
-sub applies_to           { return 'PPI::Token::Word' }
 sub supported_parameters { return () }
+sub default_severity     { return $SEVERITY_HIGH }
+sub default_themes       { return qw( more maintenance ) }
+sub applies_to           { return 'PPI::Token::Word' }
 
 #-----------------------------------------------------------------------------
 
-Readonly::Hash my %FATAL_FUNCTIONS => hashify(qw< die croak confess >);
+Readonly::Hash my %FATAL_FUNCTIONS => hashify(qw{ die croak confess });
 
 sub violates {
     my ( $self, $elem, undef ) = @_;
@@ -53,7 +52,7 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::ErrorHandling::RequireUseOfExceptions - Use exceptions instead of C<die>, C<croak>, or C<confess>.
+Perl::Critic::Policy::ErrorHandling::RequireUseOfExceptions
 
 =head1 AFFILIATION
 
@@ -71,7 +70,7 @@ Elliot Shank C<< <perl@galumph.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2008 Elliot Shank.  All rights reserved.
+Copyright (c) 2007 Elliot Shank.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -86,4 +85,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
